package base_from_yongyi_v2

import (
	"eta/eta_data_analysis/models"
	"eta/eta_data_analysis/utils"
	"fmt"
	"github.com/xuri/excelize/v2"
	"strconv"
	"strings"
	"time"
)

// HandleYongyiExcelWeekly36 涌溢样本测算
func HandleYongyiExcelWeekly36(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			fmt.Printf("HandleYongyiExcelWeekly36 涌溢样本测算 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly36 涌溢样本测算 ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	sort := 0
	nameMap := make(map[int]string)
	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		if i == 0 {
			continue
		} else if i == 1 {
			for k, text := range row {
				if text != "" {
					text = strings.TrimSpace(text)
					nameMap[k] = text
				}
			}
		} else { //数据列
			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006年1月", text, time.Local)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					// 查询当月的最后一天
					monthDate := dateT.Format(utils.FormatYearMonthDate)
					firstDayStr := monthDate + "-01"
					tmpT, _ := time.ParseInLocation(utils.FormatDate, firstDayStr, time.Local)
					date = tmpT.AddDate(0, 1, -1).Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						//utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				name, ok2 := nameMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				//fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, name)
				if strings.Contains(name, "时间") || name == "肉产量（吨）" || name == "肉产量（万吨）" || name == "断奶仔猪量" {
					continue
				}
				switch {
				case strings.Contains(name, "分娩母猪窝数"):
					unit = "窝"
				case strings.Contains(name, "窝均健仔数"):
					unit = "头"
				case strings.Contains(name, "次月断奶成活率"):
					unit = "%"
				case strings.Contains(name, "育肥出栏成活率"):
					unit = "%"
				case strings.Contains(name, "出栏量"):
					name = "出栏量"
					unit = "头"
				case strings.Contains(name, "出栏体重（公斤）"):
					name = "出栏体重"
					unit = "公斤"
				case strings.Contains(name, "出肉率"):
					unit = "%"
				case strings.Contains(name, "肉产量（公斤）"):
					name = "肉产量"
					unit = "公斤"
				case strings.Contains(name, "猪价（元/公斤）"):
					name = "猪价"
					unit = "元/公斤"
				}
				fullIndexName := fmt.Sprintf("%s/%s", namePrefix, name)
				namePingin := utils.GetFirstPingYin(name)
				fullIndexNamePingyin := namePrefixPingin + namePingin

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("IndexCode: %s", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}
