package base_from_yongyi_v2

import (
	"eta/eta_data_analysis/models"
	"eta/eta_data_analysis/utils"
	"fmt"
	"github.com/xuri/excelize/v2"
	"strconv"
	"strings"
	"time"
)

// HandleYongyiExcelDaily1 日度-商品猪出栏价
func HandleYongyiExcelDaily1(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			fmt.Printf("HandleYongyiExcelDaily1 周度-商品猪出栏价 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelDaily1 周度-商品猪出栏价ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	dateMap := make(map[int]string)
	nameMap := make(map[int]string)
	sort := 0
	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)

	stopFlag := false
	for i, row := range rows {
		fmt.Printf("当前第%d行 \n", i)
		if stopFlag {
			break
		}

		// 首行，表示时间
		if i == 0 {
			dateTmp := ""
			for k, text := range row {
				fmt.Printf("当前第%d列 \n", k)
				if k > 1 {
					text = strings.TrimSpace(text)
					if text != "" {
						// 日期
						var dateT time.Time
						dateT, e = utils.ParseExcelDateToTime(text)
						if e != nil {
							//utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
							continue
						}
						dateTmp = dateT.Format(utils.FormatDate)
					}

					dateMap[k] = dateTmp
				}
			}
		} else if i == 1 { //表示表头
			// 处理 index指标表
			for k, text := range row {
				fmt.Printf("当前第%d列 \n", k)
				if text != "" {
					nameMap[k] = text
				}
			}
		} else { //数据列
			province := ""
			for k, text := range row {
				text = strings.TrimSpace(text)
				fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					if text == "" {
						stopFlag = true
						break
					}
					province = text
					continue
				} else if k == 1 {
					continue
				} else {
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}
				date, ok1 := dateMap[k]
				if !ok1 {
					utils.FileLog.Info(fmt.Sprintf("找不到对应的日期，第%d行，第%d列， text:%s", i, k, text))
					continue
				}
				name, ok2 := nameMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				if name == "全国均价" {
					name = "全国"
				}
				fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, province)
				// 处理指标名称
				fullIndexName := fmt.Sprintf("%s/%s/%s", namePrefix, province, name)

				if name != "规模场" && name != "小散户" && name != "均价" {
					// 只处理以上三个类型，其余过滤
					continue
				}

				if fullIndexName == "商品猪出栏价/全国/均价" {
					continue
				}

				provincePingyin := utils.GetFullPingYin(province)
				namePingin := utils.GetFirstPingYin(name)
				fullIndexNamePingyin := fmt.Sprintf("%s%s%s", namePrefixPingin, provincePingyin, namePingin)

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		fmt.Printf("IndexName: %s \n", v.IndexName)
		fmt.Printf("IndexCode: %s \n", v.IndexCode)
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelDaily2 日度-商品猪标肥价差
func HandleYongyiExcelDaily2(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			fmt.Printf("HandleYongyiExcelDaily2 日度-商品猪标肥价差 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelDaily2 日度-商品猪标肥价差 ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, _, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	dateMap := make(map[int]string)
	nameMap := make(map[int]string)
	sort := 0
	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)

	stopFlag := false
	for i, row := range rows {
		fmt.Printf("当前第%d行 \n", i)
		if stopFlag {
			break
		}

		// 首行，表示时间
		if i == 0 {
			dateTmp := ""
			for k, text := range row {
				fmt.Printf("当前第%d列 \n", k)
				if text != "" {
					// 日期
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = utils.ParseExcelDateToTime(text)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					dateTmp = dateT.Format(utils.FormatDate)
				}
				dateMap[k] = dateTmp
			}
		} else if i == 1 { //表示表头
			// 处理 index指标表
			for k, text := range row {
				fmt.Printf("当前第%d列 \n", k)
				if text != "" {
					nameMap[k] = text
				}
			}
		} else { //数据列
			province := ""
			for k, text := range row {
				text = strings.TrimSpace(text)
				fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					if text == "" { // 第一列为空
						stopFlag = true
						break
					}
					province = text
					continue
				} else {
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						//utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				date, ok1 := dateMap[k]
				if !ok1 {
					utils.FileLog.Info(fmt.Sprintf("找不到对应的日期，第%d行，第%d列， text:%s", i, k, text))
					continue
				}
				name, ok2 := nameMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				if province == "全国均价" {
					province = "全国"
				}
				fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, province)
				// 处理指标名称

				// 过滤特殊的指标 放到对应的指标名称的下方

				if name != "市场标重猪" && name != "150公斤左右较标猪" && name != "175公斤左右较标猪" {
					// 只处理以上三个类型，其余过滤
					continue
				}

				if name == "150公斤左右较标猪" {
					name = "150公斤较标猪价差"
				} else if name == "175公斤左右较标猪" {
					name = "175公斤较标猪价差"
				} else if name == "市场标重猪" {
					name = "市场标重猪价"
				} else if name == "全国均价" {
					name = "全国"
				}
				fullIndexName := fmt.Sprintf("%s/%s", name, province)
				provincePingyin := utils.GetFullPingYin(province)
				namePingin := utils.GetFirstPingYin(name)
				fullIndexNamePingyin := fmt.Sprintf("%s%s%s", namePrefixPingin, namePingin, provincePingyin)

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		fmt.Printf("IndexName: %s \n", v.IndexName)
		fmt.Printf("IndexCode: %s \n", v.IndexCode)
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelDaily3 日度-商品猪全国均价和宰量
func HandleYongyiExcelDaily3(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			fmt.Printf("HandleYongyiExcelDaily3 日度-商品猪全国均价和宰量 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelDaily3 日度-商品猪全国均价和宰量 ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, _, _ := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	nameMap := make(map[int]string)
	sort := 0
	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)

	stopFlag := false
	for i, row := range rows {
		fmt.Printf("当前第%d行 \n", i)
		if stopFlag {
			break
		}
		// 首行，表示时间
		if i == 0 {
			for k, text := range row {
				fmt.Printf("当前第%d列 \n", k)
				text = strings.TrimSpace(text)
				if text != "" {
					// 日期
					nameMap[k] = text
				}
			}
		} else { //数据列
			date := ""
			for k, text := range row {
				text = strings.TrimSpace(text)
				fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					if text == "" { // 第一列为空
						stopFlag = true
						break
					}
					var dateT time.Time
					dateT, e = utils.ParseExcelDateToTime(text)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					date = dateT.Format(utils.FormatDate)
					continue
				} else {
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				name, ok2 := nameMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				if name != "全国均价" && name != "日屠宰量" {
					// 只处理以上三个类型，其余过滤
					continue
				}
				var fullIndexNamePingyin string
				if name == "全国均价" {
					name = "商品猪出拦价/全国/均价"
					fullIndexNamePingyin = "yyzxspzcljquanguojj"
					unit = "元/公斤"
				} else if name == "日屠宰量" {
					name = "商品猪日屠宰量/全国"
					fullIndexNamePingyin = "yyzxspzrtzlquanguo"
					unit = "头/日"
				}
				fullIndexName := name
				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		fmt.Printf("IndexName: %s \n", v.IndexName)
		fmt.Printf("IndexCode: %s \n", v.IndexCode)
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelDaily4 日度-屠宰企业屠宰量
func HandleYongyiExcelDaily4(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			fmt.Printf("HandleYongyiExcelDaily4 日度-屠宰企业屠宰量 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelDaily4 日度-屠宰企业屠宰量 ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	dateMap := make(map[int]string)
	sort := 0
	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)

	stopFlag := false
	for i, row := range rows {
		fmt.Printf("当前第%d行 \n", i)
		if stopFlag {
			break
		}
		// 首行，表示时间
		if i == 0 {
			for k, text := range row {
				fmt.Printf("当前第%d列 \n", k)
				if text != "" {
					// 日期
					text = strings.TrimSpace(text)
					dateSlice := strings.Split(text, "（")
					if len(dateSlice) > 1 {
						text = dateSlice[0]
					}
					var dateT time.Time
					//判断是否是数字，如果是数字，另外单独处理
					if dateFloat, e := strconv.ParseFloat(text, 64); e == nil {
						dateT, e = excelize.ExcelDateToTime(dateFloat, false)
						if e != nil {
							utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
							continue
						}
					} else {
						dateT, e = utils.ParseExcelDateToTime(text)
						if e != nil {
							/*dateT, e = time.ParseInLocation("2006/1/2", text, time.Local)
							if e != nil {*/
							utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
							continue
							//}
						}
					}
					dateMap[k] = dateT.Format(utils.FormatDate)
				}
			}
		} else { //数据列
			province := ""
			for k, text := range row {
				text = strings.TrimSpace(text)
				fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					if text == "" { // 第一列为空
						stopFlag = true
						break
					}
					province = text
					continue
				} else {
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				date, ok1 := dateMap[k]
				if !ok1 {
					utils.FileLog.Info(fmt.Sprintf("找不到对应的日期，第%d行，第%d列， text:%s", i, k, text))
					continue
				}
				if province == "合计（单位：头）" {
					continue
				}
				fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, province)
				// 处理指标名称

				// 过滤特殊的指标 放到对应的指标名称的下方
				fullIndexName := fmt.Sprintf("%s/%s", namePrefix, province)

				provincePingyin := utils.GetFullPingYin(province)
				fullIndexNamePingyin := fmt.Sprintf("%s%s", namePrefixPingin, provincePingyin)

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		fmt.Printf("IndexName: %s \n", v.IndexName)
		fmt.Printf("IndexCode: %s \n", v.IndexCode)
		indexList = append(indexList, v)
	}
	return
}
