package base_from_yongyi_v2

import (
	"eta/eta_data_analysis/models"
	"eta/eta_data_analysis/utils"
	"fmt"
	"github.com/xuri/excelize/v2"
	"strconv"
	"strings"
	"time"
)

// HandleYongyiExcelWeekly1 周度-商品猪出栏价
func HandleYongyiExcelWeekly1(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly1 周度-商品猪出栏价 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly1 周度-商品猪出栏价ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	areaMap := make(map[int]string)
	provinceMap := make(map[int]string)
	sort := 0
	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)

	mergeCellMap, err := GetMergeCells(f, sheetName)
	if err != nil {
		err = fmt.Errorf("获取合并单元格失败, sheetName: %s", sheetName)
		return
	}
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		currentMergeCells, mergeOk := mergeCellMap[i]

		// 首行，表示时间
		if i == 0 {
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k > 1 && text != "" {
					text = strings.TrimSpace(text)
					if mergeOk {
						for j, v := range currentMergeCells {
							areaMap[j] = v
							provinceMap[j] = v
						}
					}
					areaMap[k] = text
				}
			}
		} else if i == 1 { //表示表头
			// 处理 index指标表
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if text != "" {
					provinceMap[k] = text
				}
			}
		} else { //数据列
			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					continue
				} else if k == 1 {
					// 日期
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006/1/2", text, time.Local)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					date = dateT.Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else {
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}
				area, ok1 := areaMap[k]
				if !ok1 {
					err = fmt.Errorf("找不到对应的区域，第%d行，第%d列", i, k)
					return
				}
				province, ok2 := provinceMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				//fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, province)
				// 处理指标名称
				fullIndexName := fmt.Sprintf("%s/%s/%s", namePrefix, area, province)
				provincePingyin := utils.GetFullPingYin(province)
				areaPingin := utils.GetFirstPingYin(area)
				fullIndexNamePingyin := namePrefixPingin + areaPingin + provincePingyin

				if province == "全  国1" || province == "全  国2" || province == "全国1" || province == "全国2" {
					province = strings.ReplaceAll(province, " ", "")
					fullIndexName = fmt.Sprintf("%s/%s", namePrefix, province)
					provincePingyin = utils.GetFullPingYin(province)
					fullIndexNamePingyin = namePrefixPingin + provincePingyin
				}

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("indexItem%s", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly2 周度-体重
func HandleYongyiExcelWeekly2(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly1 周度-商品猪出栏价 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly1 周度-商品猪出栏价ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	areaMap := make(map[int]string)
	provinceMap := make(map[int]string)

	sort := 0
	fmt.Println("最大行")

	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	mergeCellMap, err := GetMergeCells(f, sheetName)
	if err != nil {
		err = fmt.Errorf("获取合并单元格失败, sheetName: %s", sheetName)
		return
	}
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		currentMergeCells, mergeOk := mergeCellMap[i]

		if i == 0 { // 首行，表示时间

			for k, text := range row {
				if k > 2 && text != "" {
					text = strings.TrimSpace(text)
					if mergeOk {
						for j, v := range currentMergeCells {
							areaMap[j] = v
							provinceMap[j] = v
						}
					}
					areaMap[k] = text
				}
			}
		} else if i == 1 { //表示表头
			// 处理 index指标表

			for k, text := range row {
				if text != "" {
					provinceMap[k] = text
				}
			}
		} else { //数据列

			date := ""
			name := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					continue
				} else if k == 1 {
					// 日期
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006/1/2", text, time.Local)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					date = dateT.Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else if k == 2 {
					name = text
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						//utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				area, ok1 := areaMap[k]
				if !ok1 {
					err = fmt.Errorf("找不到对应的区域，第%d行，第%d列", i, k)
					return
				}
				province, ok2 := provinceMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				//fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, province)
				// 处理指标名称
				fullIndexName := fmt.Sprintf("%s/%s/%s/%s", namePrefix, area, province, name)
				provincePingyin := utils.GetFullPingYin(province)
				areaPingin := utils.GetFirstPingYin(area)
				namePingin := utils.GetFirstPingYin(name)
				fullIndexNamePingyin := namePrefixPingin + areaPingin + provincePingyin + namePingin

				if province == "全  国1" || province == "全  国2" || province == "全国1" || province == "全国2" {
					province = strings.ReplaceAll(province, " ", "")
					fullIndexName = fmt.Sprintf("%s/%s/%s", namePrefix, province, name)
					fullIndexNamePingyin = namePrefixPingin + provincePingyin + namePingin
				}
				if name == "90kg以下" || name == "150kg以上" {
					unit = "%"
				}
				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("indexItem%s", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly3 周度-屠宰厂宰前活猪重
func HandleYongyiExcelWeekly3(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly1 周度-商品猪出栏价 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly1 周度-商品猪出栏价ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	provinceMap := make(map[int]string)

	sort := 0

	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	mergeCellMap, err := GetMergeCells(f, sheetName)
	if err != nil {
		err = fmt.Errorf("获取合并单元格失败, sheetName: %s", sheetName)
		return
	}
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		currentMergeCells, mergeOk := mergeCellMap[i]

		if i < 2 {
			continue
		}
		if i == 2 { // 首行，表示时间

			for k, text := range row {
				if k > 2 && text != "" {
					text = strings.TrimSpace(text)
					if mergeOk {
						for j, v := range currentMergeCells {
							provinceMap[j] = v
						}
					}
					provinceMap[k] = text
				}
			}
		} else if i == 3 { //表示表头
			// 处理 index指标表

			for k, text := range row {
				if text != "" {
					provinceMap[k] = text
				}
			}
		} else { //数据列

			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					continue
				} else if k == 1 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006/1/2", text, time.Local)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					date = dateT.Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else if k == 2 {
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				province, ok2 := provinceMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				if province == "较上周" {
					continue
				} else if province == "全国平均" {
					province = "全国"
				}
				//fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, province)
				// 处理指标名称
				fullIndexName := fmt.Sprintf("%s/%s", namePrefix, province)
				provincePingyin := utils.GetFullPingYin(province)
				fullIndexNamePingyin := namePrefixPingin + provincePingyin

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("indexItem%s", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly4 周度-各体重段价差
func HandleYongyiExcelWeekly4(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly1 周度-商品猪出栏价 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly1 周度-商品猪出栏价ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, _, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	provinceMap := make(map[int]string)

	sort := 0
	fmt.Println("最大行")

	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	mergeCellMap, err := GetMergeCells(f, sheetName)
	if err != nil {
		err = fmt.Errorf("获取合并单元格失败, sheetName: %s", sheetName)
		return
	}
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		currentMergeCells, mergeOk := mergeCellMap[i]

		if i == 0 {
			continue
		} else if i == 1 { //表示表头
			// 处理 index指标表

			for k, text := range row {
				if text != "" {
					text = strings.TrimSpace(text)
					if mergeOk {
						for j, v := range currentMergeCells {
							provinceMap[j] = v
						}
					}
					provinceMap[k] = text
				}
			}
		} else { //数据列

			date := ""
			name := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					continue
				} else if k == 1 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006/1/2", text, time.Local)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					date = dateT.Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else if k == 2 {
					name = text
					if name == "标猪" {
						name += "价格"
					} else {
						name += "猪价格"
					}
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						//utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				province, ok2 := provinceMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				if name != "标猪价格" && name != "150kg猪价格" && name != "175kg猪价格" && name != "200kg猪价格" {
					continue
				}

				// 处理指标名称
				fullIndexName := fmt.Sprintf("%s/%s", name, province)
				provincePingyin := utils.GetFullPingYin(province)
				namePingin := utils.GetFirstPingYin(name)
				fullIndexNamePingyin := namePrefixPingin + namePingin + provincePingyin

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		//fmt.Printf("IndexName: %s \n", v.IndexName)
		//fmt.Printf("IndexCode: %s \n", v.IndexCode)
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly5 周度-50公斤二元母猪价格
func HandleYongyiExcelWeekly5(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly1 周度-商品猪出栏价 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly1 周度-商品猪出栏价ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	provinceMap := make(map[int]string)

	sort := 0
	fmt.Println("最大行")

	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	mergeCellMap, err := GetMergeCells(f, sheetName)
	if err != nil {
		err = fmt.Errorf("获取合并单元格失败, sheetName: %s", sheetName)
		return
	}
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		currentMergeCells, mergeOk := mergeCellMap[i]

		if i == 0 {

			for k, text := range row {
				if k > 1 && text != "" {
					text = strings.TrimSpace(text)
					if mergeOk {
						for j, v := range currentMergeCells {
							provinceMap[j] = v
						}
					}
					provinceMap[k] = text
				}
			}
			continue
		} else if i == 1 { //表示表头
			// 处理 index指标表

			for k, text := range row {

				if text != "" {
					provinceMap[k] = text
				}
			}
		} else { //数据列

			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					continue
				} else if k == 1 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006/1/2", text, time.Local)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					date = dateT.Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						//utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				province, ok2 := provinceMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				if province == "全  国1" || province == "全  国2" || province == "全国1" || province == "全国2" {
					province = strings.ReplaceAll(province, " ", "")
				}
				//fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, province)
				// 处理指标名称
				fullIndexName := fmt.Sprintf("%s/%s", namePrefix, province)
				provincePingyin := utils.GetFullPingYin(province)
				fullIndexNamePingyin := namePrefixPingin + provincePingyin

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("IndexCode: %s", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly6 周度-冻品库存多样本
func HandleYongyiExcelWeekly6(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {

	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly1 周度-商品猪出栏价 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly1 周度-商品猪出栏价ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	areaMap := make(map[int]string)

	sort := 0
	fmt.Println("最大行")

	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	mergeCellMap, err := GetMergeCells(f, sheetName)
	if err != nil {
		err = fmt.Errorf("获取合并单元格失败, sheetName: %s", sheetName)
		return
	}
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		currentMergeCells, mergeOk := mergeCellMap[i]

		if i == 0 {
			continue
		} else if i == 1 { //表示表头
			// 处理 index指标表

			for k, text := range row {
				if text != "" {
					text = strings.TrimSpace(text)
					if mergeOk {
						for j, v := range currentMergeCells {
							areaMap[j] = v
						}
					}
					areaMap[k] = text
				}
			}
		} else { //数据列

			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("01-02-06", text, time.Local)
					if e != nil {
						dateT, e = time.ParseInLocation("2006/1/2", text, time.Local)
						if e != nil {
							utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
							continue
						}
					}
					date = dateT.Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				area, ok2 := areaMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				//fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, area)
				// 处理指标名称
				fullIndexName := fmt.Sprintf("%s/%s", namePrefix, area)
				areaPingyin := utils.GetFirstPingYin(area)
				if sheetName == "月度出栏完成率" {
					areaPingyin = utils.GetFullPingYin(area)
				}
				fullIndexNamePingyin := namePrefixPingin + areaPingyin

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("IndexCode: %s", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly7 月度计划出栏量
func HandleYongyiExcelWeekly7(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly1 周度-商品猪出栏价 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly1 周度-商品猪出栏价ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	provinceMap := make(map[int]string)
	firstMap := make(map[int]string)

	sort := 0
	fmt.Println("最大行")

	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	mergeCellMap, err := GetMergeCells(f, sheetName)
	if err != nil {
		err = fmt.Errorf("获取合并单元格失败, sheetName: %s", sheetName)
		return
	}
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		currentMergeCells, mergeOk := mergeCellMap[i]

		if i == 0 {
			// 处理 index指标表

			for k, text := range row {
				if text != "" {
					text = strings.TrimSpace(text)
					if mergeOk {
						for j, v := range currentMergeCells {
							firstMap[j] = v
						}
					}
					firstMap[k] = text
				}
			}
			continue
		} else if i == 1 { //表示表头
			// 处理 index指标表

			for k, text := range row {

				if text != "" {
					provinceMap[k] = text
				}
			}
		} else { //数据列

			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006年1月", text, time.Local)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					// 查询当月的最后一天
					monthDate := dateT.Format(utils.FormatYearMonthDate)
					firstDayStr := monthDate + "-01"
					tmpT, _ := time.ParseInLocation(utils.FormatDate, firstDayStr, time.Local)
					date = tmpT.AddDate(0, 1, -1).Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						//utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				province, ok1 := provinceMap[k]
				if !ok1 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				if province == "本月计划较上月实际销售" {
					continue
				}
				//fmt.Printf("当前第%d行第%d列, 当前省份: %s \n", i, k, province)
				// 处理指标名称
				fullIndexName := fmt.Sprintf("%s/%s", namePrefix, province)
				provincePingyin := utils.GetFullPingYin(province)
				fullIndexNamePingyin := namePrefixPingin + provincePingyin

				if province == "数量" {
					first, ok2 := firstMap[k]
					if !ok2 {
						continue
					}
					fullIndexName = first
					firstPingyin := utils.GetFirstPingYin(first)
					fullIndexNamePingyin = "yyzx" + firstPingyin
					unit = "万头"
				}

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("IndexCode: %s\n", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly8 月度-能繁母猪存栏（2020年2月新增）
func HandleYongyiExcelWeekly8(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly1 周度-商品猪出栏价 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly1 周度-商品猪出栏价ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	areaMap := make(map[int]string)

	sort := 0
	fmt.Println("最大行")

	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	mergeCellMap, err := GetMergeCells(f, sheetName)
	if err != nil {
		err = fmt.Errorf("获取合并单元格失败, sheetName: %s", sheetName)
		return
	}
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		currentMergeCells, mergeOk := mergeCellMap[i]

		if i <= 2 {
			continue
		} else if i == 3 { //表示表头
			// 处理 index指标表

			for k, text := range row {

				if text != "" {
					text = strings.TrimSpace(text)
					if mergeOk {
						for j, v := range currentMergeCells {
							areaMap[j] = v
						}
					}
					areaMap[k] = text
				}
			}
		} else { //数据列

			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006年1月", text, time.Local)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					// 查询当月的最后一天
					monthDate := dateT.Format(utils.FormatYearMonthDate)
					firstDayStr := monthDate + "-01"
					tmpT, _ := time.ParseInLocation(utils.FormatDate, firstDayStr, time.Local)
					date = tmpT.AddDate(0, 1, -1).Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						//utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				area, ok1 := areaMap[k]
				if !ok1 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				if area == "环比" || area == "日期" || area == "同比" {
					continue
				}
				//fmt.Printf("当前第%d行第%d列, 当前省份: %s \n", i, k, area)
				// 处理指标名称
				fullIndexName := fmt.Sprintf("%s/%s", namePrefix, area)
				areaPingyin := utils.GetFirstPingYin(area)
				fullIndexNamePingyin := namePrefixPingin + areaPingyin

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("IndexCode: %s\n", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly9 月度-小猪存栏（2020年5月新增）
func HandleYongyiExcelWeekly9(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly1 周度-商品猪出栏价 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly1 周度-商品猪出栏价ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	areaMap := make(map[int]string)

	sort := 0
	fmt.Println("最大行")

	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	mergeCellMap, err := GetMergeCells(f, sheetName)
	if err != nil {
		err = fmt.Errorf("获取合并单元格失败, sheetName: %s", sheetName)
		return
	}
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		currentMergeCells, mergeOk := mergeCellMap[i]

		if i <= 1 {
			continue
		} else if i == 2 { //表示表头
			// 处理 index指标表

			for k, text := range row {

				if text != "" {
					text = strings.TrimSpace(text)
					if mergeOk {
						for j, v := range currentMergeCells {
							areaMap[j] = v
						}
					}
					areaMap[k] = text
				}
			}
		} else { //数据列

			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006年1月", text, time.Local)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					// 查询当月的最后一天
					monthDate := dateT.Format(utils.FormatYearMonthDate)
					firstDayStr := monthDate + "-01"
					tmpT, _ := time.ParseInLocation(utils.FormatDate, firstDayStr, time.Local)
					date = tmpT.AddDate(0, 1, -1).Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						//utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				area, ok1 := areaMap[k]
				if !ok1 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				if area == "环比" || area == "日期" || area == "同比" {
					continue
				}
				//fmt.Printf("当前第%d行第%d列, 当前省份: %s \n", i, k, area)
				// 处理指标名称
				fullIndexName := fmt.Sprintf("%s/%s", namePrefix, area)
				areaPingyin := utils.GetFirstPingYin(area)
				fullIndexNamePingyin := namePrefixPingin + areaPingyin

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("IndexCode: %s\n", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly10 月度-商品猪出栏量
func HandleYongyiExcelWeekly10(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly1 周度-商品猪出栏价 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly1 周度-商品猪出栏价ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	areaMap := make(map[int]string)

	sort := 0
	fmt.Println("最大行")

	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	mergeCellMap, err := GetMergeCells(f, sheetName)
	if err != nil {
		err = fmt.Errorf("获取合并单元格失败, sheetName: %s", sheetName)
		return
	}
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		currentMergeCells, mergeOk := mergeCellMap[i]
		if i == 0 {
			continue
		} else if i == 1 { //表示表头
			// 处理 index指标表

			for k, text := range row {
				if text != "" {
					text = strings.TrimSpace(text)
					if mergeOk {
						for j, v := range currentMergeCells {
							areaMap[j] = v
						}
					}
					areaMap[k] = text
				}
			}
		} else { //数据列

			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006年1月", text, time.Local)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					// 查询当月的最后一天
					monthDate := dateT.Format(utils.FormatYearMonthDate)
					firstDayStr := monthDate + "-01"
					tmpT, _ := time.ParseInLocation(utils.FormatDate, firstDayStr, time.Local)
					date = tmpT.AddDate(0, 1, -1).Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						//utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				area, ok1 := areaMap[k]
				if !ok1 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				if area == "环比" || area == "日期" || area == "同比" || area == "较非瘟前" {
					continue
				}
				//fmt.Printf("当前第%d行第%d列, 当前省份: %s \n", i, k, area)
				// 处理指标名称
				fullIndexName := fmt.Sprintf("%s/%s", namePrefix, area)
				areaPingyin := utils.GetFirstPingYin(area)
				fullIndexNamePingyin := namePrefixPingin + areaPingyin

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("IndexCode: %s\n", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}
