package base_from_yongyi_v2

import (
	"eta/eta_data_analysis/models"
	"eta/eta_data_analysis/utils"
	"fmt"
	"github.com/xuri/excelize/v2"
	"strconv"
	"strings"
	"time"
)

// HandleYongyiExcelWeekly21 仔猪、母猪
func HandleYongyiExcelWeekly21(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly21 仔猪、母猪 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly21 仔猪、母猪 ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, _, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	provinceMap := make(map[int]string)

	sort := 0
	fmt.Println("最大行")

	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		if i == 0 {
			continue
		} else if i == 1 { //表示表头
			// 处理 index指标表
			for k, text := range row {
				if text != "" {
					text = strings.TrimSpace(text)
					provinceMap[k] = text
				}
			}
		} else { //数据列
			date := ""
			name := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006/1/2", text, time.Local)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					date = dateT.Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else if k == 1 {
					name = text
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						//	utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				province, ok2 := provinceMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}

				//fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, province)
				// 处理指标名称
				fullIndexName := fmt.Sprintf("%s/%s/%s", "仔猪价", name, province)
				provincePingyin := utils.GetFullPingYin(province)
				namePingin := utils.GetFirstPingYin(name)
				fullIndexNamePingyin := namePrefixPingin + utils.GetFirstPingYin("仔猪价") + namePingin + provincePingyin
				if strings.Contains(name, "二元母猪价") {
					fullIndexName = fmt.Sprintf("%s/%s", name, province)
					fullIndexNamePingyin = "yyzx" + namePingin + provincePingyin
				}
				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("IndexCode: %s", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly22 周度-河南屠宰白条成本
func HandleYongyiExcelWeekly22(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly22 周度-河南屠宰白条成本 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly22 周度-河南屠宰白条成本 ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	nameMap := make(map[int]string)

	sort := 0

	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		if i == 0 {
			continue
		} else if i == 1 { //表示表头
			// 处理 index指标表
			for k, text := range row {
				if text != "" {
					text = strings.TrimSpace(text)
					nameMap[k] = text
				}
			}
		} else { //数据列
			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006/1/2", text, time.Local)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					date = dateT.Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				name, ok2 := nameMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				nameSlice := strings.Split(name, "（")
				unitNew := unit
				if len(nameSlice) > 1 {
					name = nameSlice[0]
				}
				nameSlice = strings.Split(name, "\n")
				if len(nameSlice) > 1 {
					name = nameSlice[0]
				}
				switch name {
				case "生猪重量", "净白条重":
					unitNew = "kg"
				case "生猪结算", "白条成本", "6个等级白条均价":
					unitNew = "元/kg"
				case "副产品回", "屠宰费用", "白条头均利润":
					unitNew = "元/头"
				}
				if name == "预冷损耗" {
					continue
				}
				//fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, name)
				// 处理指标名称
				fullIndexName := fmt.Sprintf("%s/%s", namePrefix, name)
				namePingin := utils.GetFirstPingYin(name)
				fullIndexNamePingyin := namePrefixPingin + namePingin

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unitNew
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("IndexCode: %s", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly23 周度-淘汰母猪价格
func HandleYongyiExcelWeekly23(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly23 周度-淘汰母猪价格 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly23 周度-淘汰母猪价格 ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	provinceMap := make(map[int]string)

	sort := 0
	fmt.Println("最大行")

	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		if i == 0 {
			continue
		} else if i == 1 { //表示表头
			// 处理 index指标表
			for k, text := range row {
				if text != "" {
					text = strings.TrimSpace(text)
					provinceMap[k] = text
				}
			}
		} else { //数据列
			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					continue
				} else if k == 1 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006/1/2", text, time.Local)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					date = dateT.Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						//utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				province, ok2 := provinceMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}

				//fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, province)
				// 处理指标名称
				fullIndexName := fmt.Sprintf("%s/%s", namePrefix, province)
				provincePingyin := utils.GetFullPingYin(province)
				fullIndexNamePingyin := namePrefixPingin + provincePingyin

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("IndexCode: %s", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly24 鲜销率
func HandleYongyiExcelWeekly24(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly24 鲜销率 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly24 鲜销率 ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	provinceMap := make(map[int]string)

	sort := 0
	fmt.Println("最大行")

	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		if i <= 1 || i > 2 && i <= 5 {
			continue
		} else if i == 2 { //表示表头
			// 处理 index指标表
			for k, text := range row {
				if text != "" {
					text = strings.TrimSpace(text)
					provinceMap[k] = text
				}
			}
		} else { //数据列
			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					continue
				} else if k == 1 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006/1/2", text, time.Local)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					date = dateT.Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				province, ok2 := provinceMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}

				//fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, province)
				// 处理指标名称
				fullIndexName := fmt.Sprintf("%s/%s", namePrefix, province)
				provincePingyin := utils.GetFullPingYin(province)
				fullIndexNamePingyin := namePrefixPingin + provincePingyin

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("IndexCode: %s", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly25 周度-猪肉产品价格
func HandleYongyiExcelWeekly25(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly25 周度-猪肉产品价格 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly25 周度-猪肉产品价格 ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	provinceMap := make(map[int]string)

	sort := 0
	fmt.Println("最大行")

	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		if i == 0 {
			continue
		} else if i == 1 { //表示表头
			// 处理 index指标表
			for k, text := range row {
				if text != "" {
					text = strings.TrimSpace(text)
					provinceMap[k] = text
				}
			}
		} else { //数据列
			date := ""
			name := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					continue
				} else if k == 1 {
					text = strings.TrimSpace(text)
					dateSlice := strings.Split(text, "（")
					if len(dateSlice) > 1 {
						text = dateSlice[0]
					}
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006/1/2", text, time.Local)
					if e != nil {
						dateT, e = time.ParseInLocation("01-02-06", text, time.Local)
						if e != nil {
							utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
							continue
						}
					}
					date = dateT.Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else if k == 2 {
					name = text
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				province, ok2 := provinceMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				if strings.Contains(name, "二元母猪价") {
					continue
				}
				//fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, province)
				// 处理指标名称
				fullIndexName := fmt.Sprintf("%s/%s/%s", namePrefix, name, province)
				provincePingyin := utils.GetFullPingYin(province)
				namePingin := utils.GetFirstPingYin(name)
				fullIndexNamePingyin := namePrefixPingin + namePingin + provincePingyin
				if strings.Contains(name, "二元母猪价") {
					fullIndexName = fmt.Sprintf("%s/%s", name, province)
					fullIndexNamePingyin = "yyzx" + namePingin + provincePingyin
				}
				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		//fmt.Printf("IndexName: %s \n", v.IndexName)
		//fmt.Printf("IndexCode: %s \n", v.IndexCode)
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly26 周度-淘汰母猪价格
func HandleYongyiExcelWeekly26(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly26 周度-屠宰企业日度屠宰量 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly26 周度-屠宰企业日度屠宰量 ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	provinceMap := make(map[int]string)

	sort := 0
	fmt.Println("最大行")

	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		if i == 0 { //表示表头
			// 处理 index指标表
			for k, text := range row {
				if text != "" {
					text = strings.TrimSpace(text)
					provinceMap[k] = text
				}
			}
		} else { //数据列
			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006/1/2", text, time.Local)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					date = dateT.Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				province, ok2 := provinceMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}

				//fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, province)
				// 处理指标名称
				fullIndexName := fmt.Sprintf("%s/%s", namePrefix, province)
				provincePingyin := utils.GetFullPingYin(province)
				fullIndexNamePingyin := namePrefixPingin + provincePingyin
				if strings.Contains(province, "合计") {
					province = "合计"
					fullIndexName = fmt.Sprintf("%s/%s", namePrefix, province)
					provincePingyin = utils.GetFirstPingYin(province)
					fullIndexNamePingyin = namePrefixPingin + provincePingyin
				}
				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("IndexCode: %s", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly27 周度-屠宰新2022.10.28
func HandleYongyiExcelWeekly27(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly27 周度-屠宰新2022.10.28 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly27 周度-屠宰新2022.10.28 ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	nameMap := make(map[int]string)

	sort := 0
	fmt.Println("最大行")

	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		if i == 0 {
			continue
		} else if i == 1 { //表示表头
			// 处理 index指标表
			for k, text := range row {
				if text != "" {
					text = strings.TrimSpace(text)
					nameMap[k] = text
				}
			}
		} else { //数据列
			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					continue
				} else if k == 1 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					//判断是否是数字，如果是数字，另外单独处理
					if dateFloat, e := strconv.ParseFloat(text, 64); e == nil {
						dateT, e = excelize.ExcelDateToTime(dateFloat, false)
						if e != nil {
							utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
							continue
						}
					} else {
						dateT, e = time.ParseInLocation("2006年1月2日", text, time.Local)
						if e != nil {
							utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
							continue
						}
					}
					date = dateT.Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				name, ok2 := nameMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				if name != "规模屠宰厂全国前10家" && name != "各省规模屠宰厂100家" && name != "县区+乡镇宰杀 70家" {
					continue
				}
				//fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, name)
				// 处理指标名称不同规模屠宰厂宰杀量/县区+乡镇宰杀 70家
				name = strings.Replace(name, " ", "", -1)
				fullIndexName := fmt.Sprintf("%s/%s", namePrefix, name)
				namePingin := utils.GetFirstPingYin(name)
				fullIndexNamePingyin := namePrefixPingin + namePingin

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("IndexCode: %s", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly28 月度-淘汰母猪屠宰厂宰杀量
func HandleYongyiExcelWeekly28(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly28 月度-淘汰母猪屠宰厂宰杀量 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly28 月度-淘汰母猪屠宰厂宰杀量 ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	provinceMap := make(map[int]string)
	nameMap := make(map[int]string)
	sort := 0
	fmt.Println("最大行")

	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	mergeCellMap, err := GetMergeCells(f, sheetName)
	if err != nil {
		err = fmt.Errorf("获取合并单元格失败, sheetName: %s", sheetName)
		return
	}
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		currentMergeCells, mergeOk := mergeCellMap[i]
		if i == 0 { //表示表头
			// 处理 index指标表
			for k, text := range row {
				if text != "" {
					text = strings.TrimSpace(text)
					if mergeOk {
						for j, v := range currentMergeCells {
							provinceMap[j] = v
							nameMap[j] = v
						}
					}
					provinceMap[k] = text
				}
			}
		} else if i == 1 { //表示表头
			// 处理 index指标表
			for k, text := range row {
				if text != "" {
					text = strings.TrimSpace(text)
					nameMap[k] = text
				}
			}
		} else { //数据列
			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006年1月", text, time.Local)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					// 查询当月的最后一天
					monthDate := dateT.Format(utils.FormatYearMonthDate)
					firstDayStr := monthDate + "-01"
					tmpT, _ := time.ParseInLocation(utils.FormatDate, firstDayStr, time.Local)
					date = tmpT.AddDate(0, 1, -1).Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else if k == 1 {
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}
				province, ok2 := provinceMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				name, ok1 := nameMap[k]
				if !ok1 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				if strings.Contains(name, "环比") {
					continue
				}
				//fmt.Printf("当前第%d行第%d列, 当前省份: %s \n", i, k, province)
				// 处理指标名称
				fullIndexName := fmt.Sprintf("%s/%s%s", namePrefix, province, name)
				provincePingyin := utils.GetFullPingYin(province)
				namePingin := utils.GetFirstPingYin(name)
				fullIndexNamePingyin := namePrefixPingin + provincePingyin + namePingin

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("IndexCode: %s\n", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly29 月度-猪料销量
func HandleYongyiExcelWeekly29(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly29 月度-猪料销量 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly29 月度-猪料销量 ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	nameMap := make(map[int]string)

	sort := 0
	fmt.Println("最大行")

	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		if i == 0 {
			continue
		} else if i == 1 { //表示表头
			// 处理 index指标表
			for k, text := range row {
				if text != "" {
					text = strings.TrimSpace(text)
					nameMap[k] = text
				}
			}
		} else { //数据列
			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					//判断是否是数字，如果是数字，另外单独处理
					if dateFloat, e := strconv.ParseFloat(text, 64); e == nil {
						dateT, e = excelize.ExcelDateToTime(dateFloat, false)
						if e != nil {
							utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
							continue
						}
					} else {
						dateT, e = time.ParseInLocation("2006年1月", text, time.Local)
						if e != nil {
							utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
							continue
						}
					}
					// 查询当月的最后一天
					monthDate := dateT.Format(utils.FormatYearMonthDate)
					firstDayStr := monthDate + "-01"
					tmpT, _ := time.ParseInLocation(utils.FormatDate, firstDayStr, time.Local)
					date = tmpT.AddDate(0, 1, -1).Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				name, ok2 := nameMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}

				//fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, name)

				fullIndexName := fmt.Sprintf("%s/%s", namePrefix, name)
				namePingin := utils.GetFirstPingYin(name)
				fullIndexNamePingyin := namePrefixPingin + namePingin

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("IndexCode: %s", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly30 月度-屠宰企业开工率
func HandleYongyiExcelWeekly30(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly30 月度-屠宰企业开工率 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly30 月度-屠宰企业开工率 ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	sort := 0
	fmt.Println("最大行")

	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		if i > 0 { //数据列
			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006年1月", text, time.Local)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					// 查询当月的最后一天
					monthDate := dateT.Format(utils.FormatYearMonthDate)
					firstDayStr := monthDate + "-01"
					tmpT, _ := time.ParseInLocation(utils.FormatDate, firstDayStr, time.Local)
					date = tmpT.AddDate(0, 1, -1).Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				name := "屠宰企业开工率全国平均"
				//fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, name)

				fullIndexName := fmt.Sprintf("%s%s", namePrefix, name)
				namePingin := utils.GetFirstPingYin(name)
				fullIndexNamePingyin := namePrefixPingin + namePingin

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("IndexCode: %s", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}
