package base_from_yongyi_v2

import (
	"eta/eta_data_analysis/models"
	"eta/eta_data_analysis/utils"
	"fmt"
	"regexp"
	"strconv"
	"strings"
	"time"

	"github.com/xuri/excelize/v2"
)

// HandleYongyiExcelWeekly31 月度-屠宰厂公母比例
func HandleYongyiExcelWeekly31(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly31 月度-屠宰厂公母比例 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly31 月度-屠宰厂公母比例 ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	sort := 0
	nameMap := make(map[int]string)
	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		if i == 0 {
			for k, text := range row {
				if text != "" {
					text = strings.TrimSpace(text)
					nameMap[k] = text
				}
			}
		} else { //数据列
			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006年1月", text, time.Local)
					if e != nil {
						text = strings.TrimSpace(text)
						dateSlice := strings.Split(text, "-")
						if len(dateSlice) <= 1 {
							utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, text))
							continue
						}
						dateT, e = time.ParseInLocation("2006年1月2日", dateSlice[0], time.Local)
						if e != nil {
							utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
							continue
						}
						date = dateT.Format("2006年1月") + dateSlice[1]
						dateT, e = time.ParseInLocation("2006年1月2日", date, time.Local)
						if e != nil {
							utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
							continue
						}
						date = dateT.Format(utils.FormatDate)
					} else {
						// 查询当月的最后一天
						monthDate := dateT.Format(utils.FormatYearMonthDate)
						firstDayStr := monthDate + "-01"
						tmpT, _ := time.ParseInLocation(utils.FormatDate, firstDayStr, time.Local)
						date = tmpT.AddDate(0, 1, -1).Format(utils.FormatDate)
					}
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				name, ok2 := nameMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				//fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, name)
				unit = "头"
				if strings.Contains(name, "占比") {
					unit = "%"
				}
				fullIndexName := fmt.Sprintf("%s%s", namePrefix, name)
				namePingin := utils.GetFirstPingYin(name)
				fullIndexNamePingyin := namePrefixPingin + namePingin

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("IndexCode: %s", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly32 月度-生产指标（2021.5.7新增）
func HandleYongyiExcelWeekly32(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly32 月度-生产指标（2021.5.7新增） ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly32 月度-生产指标（2021.5.7新增） ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	sort := 0
	nameMap := make(map[int]string)
	provinceMap := make(map[int]string)
	mergeCellMap, err := GetMergeCells(f, sheetName)
	if err != nil {
		err = fmt.Errorf("获取合并单元格失败, sheetName: %s", sheetName)
		return
	}
	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		currentMergeCells, mergeOk := mergeCellMap[i]
		if i == 0 {
			for k, text := range row {
				if text != "" {
					if mergeOk {
						for j, v := range currentMergeCells {
							provinceMap[j] = v
						}
					}
					provinceMap[k] = text
				}
			}
		} else if i == 1 {
			for k, text := range row {
				if text != "" {
					nameMap[k] = text
				}
			}
		} else { //数据列
			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006年1月", text, time.Local)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					// 查询当月的最后一天
					monthDate := dateT.Format(utils.FormatYearMonthDate)
					firstDayStr := monthDate + "-01"
					tmpT, _ := time.ParseInLocation(utils.FormatDate, firstDayStr, time.Local)
					date = tmpT.AddDate(0, 1, -1).Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}
				province, ok1 := provinceMap[k]
				if !ok1 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				name, ok2 := nameMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				if strings.Contains(name, "环比") {
					continue
				}
				//fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, name)
				unit = "头"
				if strings.Contains(name, "率") {
					unit = "%"
				}
				fullIndexName := fmt.Sprintf("%s/%s/%s", namePrefix, province, name)
				provincePingyin := utils.GetFullPingYin(province)
				namePingin := utils.GetFirstPingYin(name)
				fullIndexNamePingyin := namePrefixPingin + provincePingyin + namePingin

				if province == "五省合计数量" || province == "五省平均水平" {
					provincePingyin = utils.GetFirstPingYin(province)
					fullIndexNamePingyin = namePrefixPingin + provincePingyin + namePingin
				}

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("IndexCode: %s", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly33 月度-生产指标2
func HandleYongyiExcelWeekly33(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly33 月度-生产指标2ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly33 月度-生产指标2 ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	sort := 0
	nameMap := make(map[int]string)
	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		if i == 0 {
			continue
		} else if i == 1 {
			for k, text := range row {
				if text != "" {
					text = strings.TrimSpace(text)
					nameMap[k] = text
				}
			}
		} else { //数据列
			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006年1月", text, time.Local)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					// 查询当月的最后一天
					monthDate := dateT.Format(utils.FormatYearMonthDate)
					firstDayStr := monthDate + "-01"
					tmpT, _ := time.ParseInLocation(utils.FormatDate, firstDayStr, time.Local)
					date = tmpT.AddDate(0, 1, -1).Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}

				name, ok2 := nameMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				//fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, name)

				fullIndexName := fmt.Sprintf("%s/%s", namePrefix, name)
				namePingin := utils.GetFirstPingYin(name)
				fullIndexNamePingyin := namePrefixPingin + namePingin
				unit = "头"
				if strings.Contains(name, "率") {
					unit = "%"
				}
				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("IndexCode: %s", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly34 月度-二元三元能繁比例
func HandleYongyiExcelWeekly34(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly34 月度-二元三元能繁比例ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly34 月度-二元三元能繁比例 ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	sort := 0
	year := ""
	nameMap := make(map[int]string)
	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		if i == 0 {
			for k, text := range row {
				if k > 3 && text != "" {
					text = strings.TrimSpace(text)
					nameMap[k] = text
				}
			}
		} else { //数据列
			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k <= 3 || k > 8 {
					continue
				} else if k == 4 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					//判断是否是数字，如果是数字，另外单独处理
					if dateFloat, e := strconv.ParseFloat(text, 64); e == nil {
						dateT, e = excelize.ExcelDateToTime(dateFloat, false)
						if e != nil {
							utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
							continue
						}
					} else {
						dateSlice := strings.Split(text, "年")
						if len(dateSlice) >= 2 {
							year = dateSlice[0]
						} else {
							text = fmt.Sprintf("%s年%s", year, text)
						}
						fmt.Println(text)

						dateT, e = time.ParseInLocation("2006年1月", text, time.Local)
						if e != nil {
							utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
							continue
						}
					}

					// 查询当月的最后一天
					monthDate := dateT.Format(utils.FormatYearMonthDate)
					firstDayStr := monthDate + "-01"
					tmpT, _ := time.ParseInLocation(utils.FormatDate, firstDayStr, time.Local)
					date = tmpT.AddDate(0, 1, -1).Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}
				if date == "" {
					continue
				}
				name, ok2 := nameMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				//fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, name)
				name += "比例"
				fullIndexName := fmt.Sprintf("%s/%s", namePrefix, name)
				namePingin := utils.GetFirstPingYin(name)
				fullIndexNamePingyin := namePrefixPingin + namePingin

				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("IndexCode: %s", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly35 月度-能繁母猪存栏量
func HandleYongyiExcelWeekly35(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly35 月度-能繁母猪存栏量 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly35 月度-能繁母猪存栏量 ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	// 获取指标分类
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// 遍历行读取
	indexList = make([]*models.YongyiExcelIndex, 0)
	sort := 0
	nameMap := make(map[int]string)
	// 指标名称
	indexMap := make(map[string]*models.YongyiExcelIndex)
	for i, row := range rows {
		//fmt.Printf("当前第%d行 \n", i)
		if i == 0 {
			continue
		} else if i == 1 {
			for k, text := range row {
				if text != "" {
					nameMap[k] = text
				}
			}
		} else { //数据列
			date := ""
			for k, text := range row {
				//fmt.Printf("当前第%d列 \n", k)
				if k == 0 {
					text = strings.TrimSpace(text)
					var dateT time.Time
					dateT, e = time.ParseInLocation("2006年1月", text, time.Local)
					if e != nil {
						utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 读取行，时间列失败 Err:%s", sheetName, i, k, e))
						continue
					}
					// 查询当月的最后一天
					monthDate := dateT.Format(utils.FormatYearMonthDate)
					firstDayStr := monthDate + "-01"
					tmpT, _ := time.ParseInLocation(utils.FormatDate, firstDayStr, time.Local)
					date = tmpT.AddDate(0, 1, -1).Format(utils.FormatDate)
					fmt.Println(date)
					continue
				} else {
					// 判断出不是字符的，则过滤
					if text == "" {
						continue
					}
					if strings.Contains(text, "%") {
						text = strings.Replace(text, "%", "", 1)
					}
					_, e := strconv.ParseFloat(text, 64)
					if e != nil {
						//utils.FileLog.Info(fmt.Sprintf("sheet：%s 第%d行, 第%d列 strconv.ParseFloat Err:%s", sheetName, i, k, e))
						continue
					}
				}
				name, ok2 := nameMap[k]
				if !ok2 {
					err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k)
					return
				}
				if strings.Contains(name, "环比") || strings.Contains(name, "同比") || strings.Contains(name, "日期") {
					continue
				}
				//fmt.Printf("当前第%d行第%d列, 当前省份%s \n", i, k, name)

				fullIndexName := fmt.Sprintf("%s/%s", namePrefix, name)
				namePingin := utils.GetFirstPingYin(name)
				fullIndexNamePingyin := namePrefixPingin + namePingin
				unit = "头"
				if name == "较非瘟前" {
					area, ok3 := nameMap[k-3]
					if !ok3 {
						err = fmt.Errorf("找不到对应的列名，第%d行，第%d列", i, k-3)
						return
					}
					fullIndexName = fmt.Sprintf("%s/%s%s", namePrefix, area, name)
					namePingin = utils.GetFirstPingYin(area + name)
					fullIndexNamePingyin = namePrefixPingin + namePingin
					unit = "%"
				}
				indexItem, okIndex := indexMap[fullIndexName]
				if !okIndex {
					// 新增指标
					indexItem = new(models.YongyiExcelIndex)
					indexItem.IndexName = fullIndexName
					indexItem.ClassifyName = classifyName
					indexItem.ClassifySort = classifySort
					indexItem.IndexCode = fullIndexNamePingyin
					indexItem.Frequency = frequency
					indexItem.Sort = sort
					indexItem.Unit = unit
					indexItem.ExcelDataMap = make(map[string]string)
					sort++
				}
				//fmt.Printf("IndexCode: %s", indexItem.IndexCode)

				indexItem.ExcelDataMap[date] = text
				indexMap[fullIndexName] = indexItem
				continue
			}
		}
	}
	for _, v := range indexMap {
		indexList = append(indexList, v)
	}
	return
}

// HandleYongyiExcelWeekly37 周度-养殖利润
func HandleYongyiExcelWeekly37(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly35 月度-能繁母猪存栏量 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly37 周度-养殖利润 ErrMsg: %s", err.Error()))
		}
	}()
	col, e := f.GetCols(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetCols err: %s", e.Error())
		return
	}
	yearReg := regexp.MustCompile(`^\d{4}年$`)
	// 获取指标信息
	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	// GetBaseInfo(sheetName)
	indexList = make([]*models.YongyiExcelIndex, 0)

	indexInfoMap := make(map[string]*models.YongyiExcelIndex)
	var indexName string
	var weekIndexMap = make(map[int]int)
	var sort = 0
	for i, c := range col {
		if len(c) < 2 {
			continue
		}
		if i == 0 {
			// 记录周度索引
			for j, v := range c {
				vInt, e := strconv.Atoi(v)
				if e != nil {
					continue
				}
				weekIndexMap[j] = vInt
			}
		}
		if strings.TrimSpace(c[1]) != "" {
			indexName = strings.TrimSpace(c[1])
		}
		if indexName == "" {
			continue
		}
		if len(c) < 4 {
			continue
		}
		// 匹配 2021年 的格式
		if ok := yearReg.MatchString(c[2]); !ok {
			continue
		}
		yearStr := c[2][:4]
		year, e := strconv.Atoi(yearStr)
		if e != nil {
			continue
		}
		if indexInfo, ok := indexInfoMap[indexName]; !ok {
			tmpYongyiIndex := new(models.YongyiExcelIndex)
			tmpYongyiIndex.IndexName = namePrefix + "/" + indexName
			tmpYongyiIndex.ClassifyName = classifyName
			tmpYongyiIndex.ClassifySort = classifySort
			tmpYongyiIndex.IndexCode = namePrefixPingin + utils.GetFirstPingYin(indexName)
			tmpYongyiIndex.Frequency = frequency
			tmpYongyiIndex.Unit = unit
			tmpYongyiIndex.Sort = sort
			tmpYongyiIndex.ExcelDataMap = make(map[string]string)
			for j, v := range c[3:] {
				dataTime := getSundayOfWeek(year, weekIndexMap[j+3])
				if isValueValid(v) {
					tmpYongyiIndex.ExcelDataMap[dataTime] = v
				}
			}
			indexInfoMap[indexName] = tmpYongyiIndex
			indexList = append(indexList, tmpYongyiIndex)
			sort++
		} else {
			for j, v := range c[3:] {
				dataTime := getSundayOfWeek(year, weekIndexMap[j+3])
				if isValueValid(v) {
					indexInfo.ExcelDataMap[dataTime] = v
				}
			}
		}
	}
	utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly37 周度-养殖利润 指标列表：%v", indexList))
	return
}

// HandleYongyiExcelWeekly38 华东冻品价格
func HandleYongyiExcelWeekly38(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly35 月度-能繁母猪存栏量 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly37 周度-养殖利润 ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	if len(rows) < 2 {
		err = fmt.Errorf("sheet %s 行数小于2", sheetName)
		return
	}

	mergeCellMap, e := getMergeCellValMap(f, sheetName)
	if e != nil {
		err = fmt.Errorf("getMergeCellValMap err: %s", e.Error())
		return
	}
	sort := 0
	var indexNamePart1, indexNamePart2 string
	indexNamePart3 := make(map[int]string)
	indexInfoMap := make(map[string]*models.YongyiExcelIndex)
	dateTimeIndexMap := make(map[int]string)
	maxLen := 0
	for _, row := range rows {
		if len(row) > maxLen {
			maxLen = len(row)
		}
	}
	for k, v := range mergeCellMap {
		axis := strings.Split(k, ":")
		if len(axis) != 2 {
			continue
		}
		x, y := axis[0], axis[1]
		xInt, e := strconv.Atoi(x)
		if e != nil {
			continue
		}
		yInt, e := strconv.Atoi(y)
		if e != nil {
			continue
		}
		tmpList := make([]string, maxLen)
		copy(tmpList, rows[yInt-1])
		tmpList[xInt-1] = v
		rows[yInt-1] = tmpList
	}

	for i, row := range rows {
		if i == 0 {
			continue
		}
		// 日期列
		if i == 1 {
			for j, cell := range row {
				if cell == "" {
					continue
				}
				dateInt, err := strconv.Atoi(cell)
				if err != nil {
					continue
				}
				dateTimeIndexMap[j] = excelDateToTimeDateStr(dateInt)
			}
		}
		// 指标名称列3
		if i == 2 {
			for j, cell := range row[2:] {
				if cell == "" {
					continue
				}
				indexNamePart3[j] = cell
			}
		}
		if i > 2 {
			for j, cell := range row {
				if j == 0 && cell != "" {
					indexNamePart1 = row[0]
				}
				if j == 1 && cell != "" {
					indexNamePart2 = row[1]
				}
				if indexNamePart1 == "" || indexNamePart2 == "" {
					continue
				}
				namePart3, ok := indexNamePart3[j-2]
				if !ok {
					continue
				}
				indexName := fmt.Sprintf("%s/%s/%s", indexNamePart1, indexNamePart2, namePart3)
				if indexInfo, ok := indexInfoMap[indexName]; !ok {
					tmpYongyiIndex := new(models.YongyiExcelIndex)
					tmpYongyiIndex.IndexName = namePrefix + "/" + indexName
					tmpYongyiIndex.ClassifyName = classifyName
					tmpYongyiIndex.ClassifySort = classifySort
					tmpIndexName := strings.ReplaceAll(indexName, "/", "")
					tmpYongyiIndex.IndexCode = namePrefixPingin + utils.GetFirstPingYin(tmpIndexName)
					tmpYongyiIndex.Frequency = frequency
					tmpYongyiIndex.Unit = unit
					tmpYongyiIndex.Sort = sort
					tmpYongyiIndex.ExcelDataMap = make(map[string]string)
					val, ok := getCellValue(cell)
					if !ok {
						continue
					}
					tmpYongyiIndex.ExcelDataMap[dateTimeIndexMap[j]] = val
					indexInfoMap[indexName] = tmpYongyiIndex
					indexList = append(indexList, tmpYongyiIndex)
					sort++
				} else {
					val, ok := getCellValue(cell)
					if !ok {
						continue
					}
					indexInfo.ExcelDataMap[dateTimeIndexMap[j]] = val
				}
			}
		}
	}
	utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly38 华东冻品价格 更新指标数量：%d", len(indexList)))
	return
}

// HandleYongyiExcelWeekly39 运费
func HandleYongyiExcelWeekly39(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			//fmt.Printf("HandleYongyiExcelWeekly35 月度-能繁母猪存栏量 ErrMsg: %s\n", err.Error())
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly39 月度-能繁母猪存栏量 ErrMsg: %s", err.Error()))
		}
	}()

	rows, e := f.GetRows(sheetName)
	if e != nil {
		err = fmt.Errorf("f GetRows err: %s", e.Error())
		return
	}

	classifyName, classifySort, frequency, unit, namePrefix, namePrefixPingin := GetBaseInfo(sheetName)
	if len(rows) < 2 {
		err = fmt.Errorf("sheet %s 行数小于2", sheetName)
		return
	}
	var dataTime string
	var sort int
	indexInfoMap := make(map[string]*models.YongyiExcelIndex)
	for i, row := range rows {
		if i <= 1 {
			continue
		}
		if len(row) <= 3 {
			continue
		}
		tmpDate, err := time.Parse("01-02-06", row[2])
		if err == nil {
			dataTime = tmpDate.Format(utils.FormatDate)
		}
		var fromSrc, toDst string
		if len([]rune(row[0])) == 2 && len([]rune(row[1])) == 2 {
			fromSrc = row[0]
			toDst = row[1]
		}
		if fromSrc == "" || toDst == "" {
			continue
		}
		indexName := fmt.Sprintf("%s/%s至%s", namePrefix, fromSrc, toDst)
		if indexInfo, ok := indexInfoMap[indexName]; !ok {
			tmpYongyiIndex := new(models.YongyiExcelIndex)
			tmpYongyiIndex.IndexName = indexName
			tmpYongyiIndex.ClassifyName = classifyName
			tmpYongyiIndex.ClassifySort = classifySort
			tmpIndexNameSuffix := fmt.Sprintf("%s至%s", fromSrc, toDst)
			tmpYongyiIndex.IndexCode = namePrefixPingin + utils.GetFirstPingYin(tmpIndexNameSuffix)
			tmpYongyiIndex.Frequency = frequency
			tmpYongyiIndex.Unit = unit
			tmpYongyiIndex.Sort = sort
			tmpYongyiIndex.ExcelDataMap = make(map[string]string)
			val, ok := getCellValue(row[2])
			if !ok {
				continue
			}
			tmpYongyiIndex.ExcelDataMap[dataTime] = val
			indexInfoMap[indexName] = tmpYongyiIndex
			indexList = append(indexList, tmpYongyiIndex)
			sort++
		} else {
			val, ok := getCellValue(row[2])
			if !ok {
				continue
			}
			indexInfo.ExcelDataMap[dataTime] = val
		}
	}
	utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly39 运费 更新指标数量：%d", len(indexList)))
	return
}

// HandleYongyiExcelWeekly40 国产冻品2-4号肉价格
func HandleYongyiExcelWeekly40(f *excelize.File, sheetName string) (indexList []*models.YongyiExcelIndex, err error) {
	defer func() {
		if err != nil {
			utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly40 国产冻品2-4号肉价格 ErrMsg: %s", err.Error()))
		}
	}()
	rows, err := f.GetRows(sheetName)
	if err != nil {
		err = fmt.Errorf("f GetRows err: %s", err.Error())
		return
	}
	className, classSort, frequency, unit, _, namePrefixPingin := GetBaseInfo(sheetName)

	var indexName string
	var sort int
	re := regexp.MustCompile(`[+-]?[0-9]*\.?[0-9]+`)
	indexList = make([]*models.YongyiExcelIndex, 0)
	monthIndexMap := make(map[int]int)
	indexInfoMap := make(map[string]*models.YongyiExcelIndex)
	for _, row := range rows {
		if len(row) == 0 {
			indexName = ""
			continue
		}
		if strings.Contains(row[0], "冻猪") {
			indexName = strings.TrimSpace(row[0])
		}
		if indexName == "" {
			continue
		}
		var year int
		for i, cell := range row {
			if i == 0 && strings.Contains(cell, "年销价") {
				if tmp := re.FindString(cell); tmp != "" {
					year, err = strconv.Atoi("20" + tmp)
					if err != nil {
						continue
					}
				}
			} else if strings.Contains(cell, "月") {
				if month := re.FindString(cell); month != "" {
					mo, err := strconv.Atoi(month)
					if err != nil {
						continue
					}
					monthIndexMap[i] = mo
				}
			}
			if re.MatchString(cell) {
				if indexInfo, ok := indexInfoMap[indexName]; !ok {
					if isValueValid(cell) {
						tmpYongyiIndex := new(models.YongyiExcelIndex)
						tmpYongyiIndex.IndexName = indexName
						tmpYongyiIndex.ClassifyName = className
						tmpYongyiIndex.ClassifySort = classSort
						tmpYongyiIndex.IndexCode = namePrefixPingin + utils.GetFirstPingYin(indexName)
						tmpYongyiIndex.Frequency = frequency
						tmpYongyiIndex.Unit = unit
						tmpYongyiIndex.Sort = sort
						tmpYongyiIndex.ExcelDataMap = make(map[string]string)
						date := LastDayOfMonth(year, time.Month(monthIndexMap[i]))
						tmpYongyiIndex.ExcelDataMap[date] = cell
						indexInfoMap[indexName] = tmpYongyiIndex
						indexList = append(indexList, tmpYongyiIndex)
						sort++
					}
				} else {
					if isValueValid(cell) {
						date := LastDayOfMonth(year, time.Month(monthIndexMap[i]))
						indexInfo.ExcelDataMap[date] = cell
					}
				}
			}
		}
	}
	utils.FileLog.Info(fmt.Sprintf("HandleYongyiExcelWeekly40 国产冻品2-4号肉价格 更新指标数量：%d", len(indexList)))
	return
}
